summaryrefslogtreecommitdiffstats
path: root/lib/compatibility/kmdi/qextmdi/kmdichildfrm.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit6c79d50fa9fbdff7f69ca57a8ab5fcc942375593 (patch)
treef47737d56c3239a0d8bc600674f0ca04b6e30d6e /lib/compatibility/kmdi/qextmdi/kmdichildfrm.h
parent36c36b53a129509d56fdaa0a7c9fcbcacd0c5826 (diff)
downloadtdewebdev-6c79d50fa9fbdff7f69ca57a8ab5fcc942375593.tar.gz
tdewebdev-6c79d50fa9fbdff7f69ca57a8ab5fcc942375593.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdewebdev@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'lib/compatibility/kmdi/qextmdi/kmdichildfrm.h')
-rw-r--r--lib/compatibility/kmdi/qextmdi/kmdichildfrm.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/compatibility/kmdi/qextmdi/kmdichildfrm.h b/lib/compatibility/kmdi/qextmdi/kmdichildfrm.h
index c808e088..9569094a 100644
--- a/lib/compatibility/kmdi/qextmdi/kmdichildfrm.h
+++ b/lib/compatibility/kmdi/qextmdi/kmdichildfrm.h
@@ -54,7 +54,7 @@ class KMDI_EXPORT KMdiWin32IconButton : public TQLabel
Q_OBJECT
TQ_OBJECT
public:
- KMdiWin32IconButton( TQWidget* tqparent, const char* name = 0 );
+ KMdiWin32IconButton( TQWidget* parent, const char* name = 0 );
virtual void mousePressEvent( TQMouseEvent* );
signals:
@@ -185,7 +185,7 @@ public:
/**
* Creates a new KMdiChildFrm class.
*/
- KMdiChildFrm( KMdiChildArea *tqparent );
+ KMdiChildFrm( KMdiChildArea *parent );
/**
* Destroys this KMdiChildFrm
@@ -242,7 +242,7 @@ public:
inline MdiWindowState state() const { return m_state; }
/**
* Returns the inner client area of the tqparent of this (which is KMdiChildArea).
*/
TQRect mdiAreaContentsRect() const;
@@ -242,7 +242,7 @@ public:
inline MdiWindowState state() const { return m_state; }
/**
- * Returns the inner client area of the tqparent of this (which is KMdiChildArea).
+ * Returns the inner client area of the parent of this (which is KMdiChildArea).
*/
TQRect mdiAreaContentsRect() const;